@@ -1,8 +1,8 @@
 from holon.HolonicAgent import HolonicAgent
 from navi.walk.WalkGuide import WalkGuide
 
-class RouteFind(HolonicAgent) :
-    def __init__(self):
-        super().__init__()
+class RouteFind(HolonicAgent):
+    def __init__(self, cfg):
+        super().__init__(cfg)
 
 
