@@ -1,7 +1,7 @@
 from holon.HolonicAgent import HolonicAgent
 
 class KanbanDetect(HolonicAgent):
-    def __init__(self):
-        super().__init__()
+    def __init__(self, cfg):
+        super().__init__(cfg)
 
 
